@@ -111,8 +111,7 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import (
     MaintenanceWindowResourceTypeType,
@@ -260,7 +259,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class DescribeActivationsPaginator(Boto3Paginator):
+class DescribeActivationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeActivations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeactivationspaginator)
@@ -278,7 +277,7 @@ class DescribeActivationsPaginator(Boto3Paginator):
         """
 
 
-class DescribeAssociationExecutionTargetsPaginator(Boto3Paginator):
+class DescribeAssociationExecutionTargetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAssociationExecutionTargets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeassociationexecutiontargetspaginator)
@@ -298,7 +297,7 @@ class DescribeAssociationExecutionTargetsPaginator(Boto3Paginator):
         """
 
 
-class DescribeAssociationExecutionsPaginator(Boto3Paginator):
+class DescribeAssociationExecutionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAssociationExecutions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeassociationexecutionspaginator)
@@ -317,7 +316,7 @@ class DescribeAssociationExecutionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeAutomationExecutionsPaginator(Boto3Paginator):
+class DescribeAutomationExecutionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAutomationExecutions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeautomationexecutionspaginator)
@@ -335,7 +334,7 @@ class DescribeAutomationExecutionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeAutomationStepExecutionsPaginator(Boto3Paginator):
+class DescribeAutomationStepExecutionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAutomationStepExecutions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeautomationstepexecutionspaginator)
@@ -355,7 +354,7 @@ class DescribeAutomationStepExecutionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeAvailablePatchesPaginator(Boto3Paginator):
+class DescribeAvailablePatchesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAvailablePatches)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeavailablepatchespaginator)
@@ -373,7 +372,7 @@ class DescribeAvailablePatchesPaginator(Boto3Paginator):
         """
 
 
-class DescribeEffectiveInstanceAssociationsPaginator(Boto3Paginator):
+class DescribeEffectiveInstanceAssociationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeEffectiveInstanceAssociations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeeffectiveinstanceassociationspaginator)
@@ -388,7 +387,7 @@ class DescribeEffectiveInstanceAssociationsPaginator(Boto3Paginator):
         """
 
 
-class DescribeEffectivePatchesForPatchBaselinePaginator(Boto3Paginator):
+class DescribeEffectivePatchesForPatchBaselinePaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeEffectivePatchesForPatchBaseline)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeeffectivepatchesforpatchbaselinepaginator)
@@ -403,7 +402,7 @@ class DescribeEffectivePatchesForPatchBaselinePaginator(Boto3Paginator):
         """
 
 
-class DescribeInstanceAssociationsStatusPaginator(Boto3Paginator):
+class DescribeInstanceAssociationsStatusPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstanceAssociationsStatus)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeinstanceassociationsstatuspaginator)
@@ -418,7 +417,7 @@ class DescribeInstanceAssociationsStatusPaginator(Boto3Paginator):
         """
 
 
-class DescribeInstanceInformationPaginator(Boto3Paginator):
+class DescribeInstanceInformationPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstanceInformation)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeinstanceinformationpaginator)
@@ -437,7 +436,7 @@ class DescribeInstanceInformationPaginator(Boto3Paginator):
         """
 
 
-class DescribeInstancePatchStatesPaginator(Boto3Paginator):
+class DescribeInstancePatchStatesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstancePatchStates)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeinstancepatchstatespaginator)
@@ -452,7 +451,7 @@ class DescribeInstancePatchStatesPaginator(Boto3Paginator):
         """
 
 
-class DescribeInstancePatchStatesForPatchGroupPaginator(Boto3Paginator):
+class DescribeInstancePatchStatesForPatchGroupPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstancePatchStatesForPatchGroup)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeinstancepatchstatesforpatchgrouppaginator)
@@ -471,7 +470,7 @@ class DescribeInstancePatchStatesForPatchGroupPaginator(Boto3Paginator):
         """
 
 
-class DescribeInstancePatchesPaginator(Boto3Paginator):
+class DescribeInstancePatchesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstancePatches)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeinstancepatchespaginator)
@@ -490,7 +489,7 @@ class DescribeInstancePatchesPaginator(Boto3Paginator):
         """
 
 
-class DescribeInventoryDeletionsPaginator(Boto3Paginator):
+class DescribeInventoryDeletionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInventoryDeletions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeinventorydeletionspaginator)
@@ -505,7 +504,7 @@ class DescribeInventoryDeletionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeMaintenanceWindowExecutionTaskInvocationsPaginator(Boto3Paginator):
+class DescribeMaintenanceWindowExecutionTaskInvocationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowExecutionTaskInvocations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describemaintenancewindowexecutiontaskinvocationspaginator)
@@ -525,7 +524,7 @@ class DescribeMaintenanceWindowExecutionTaskInvocationsPaginator(Boto3Paginator)
         """
 
 
-class DescribeMaintenanceWindowExecutionTasksPaginator(Boto3Paginator):
+class DescribeMaintenanceWindowExecutionTasksPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowExecutionTasks)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describemaintenancewindowexecutiontaskspaginator)
@@ -544,7 +543,7 @@ class DescribeMaintenanceWindowExecutionTasksPaginator(Boto3Paginator):
         """
 
 
-class DescribeMaintenanceWindowExecutionsPaginator(Boto3Paginator):
+class DescribeMaintenanceWindowExecutionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowExecutions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describemaintenancewindowexecutionspaginator)
@@ -563,7 +562,7 @@ class DescribeMaintenanceWindowExecutionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeMaintenanceWindowSchedulePaginator(Boto3Paginator):
+class DescribeMaintenanceWindowSchedulePaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowSchedule)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describemaintenancewindowschedulepaginator)
@@ -584,7 +583,7 @@ class DescribeMaintenanceWindowSchedulePaginator(Boto3Paginator):
         """
 
 
-class DescribeMaintenanceWindowTargetsPaginator(Boto3Paginator):
+class DescribeMaintenanceWindowTargetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowTargets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describemaintenancewindowtargetspaginator)
@@ -603,7 +602,7 @@ class DescribeMaintenanceWindowTargetsPaginator(Boto3Paginator):
         """
 
 
-class DescribeMaintenanceWindowTasksPaginator(Boto3Paginator):
+class DescribeMaintenanceWindowTasksPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowTasks)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describemaintenancewindowtaskspaginator)
@@ -622,7 +621,7 @@ class DescribeMaintenanceWindowTasksPaginator(Boto3Paginator):
         """
 
 
-class DescribeMaintenanceWindowsPaginator(Boto3Paginator):
+class DescribeMaintenanceWindowsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindows)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describemaintenancewindowspaginator)
@@ -640,7 +639,7 @@ class DescribeMaintenanceWindowsPaginator(Boto3Paginator):
         """
 
 
-class DescribeMaintenanceWindowsForTargetPaginator(Boto3Paginator):
+class DescribeMaintenanceWindowsForTargetPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowsForTarget)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describemaintenancewindowsfortargetpaginator)
@@ -659,7 +658,7 @@ class DescribeMaintenanceWindowsForTargetPaginator(Boto3Paginator):
         """
 
 
-class DescribeOpsItemsPaginator(Boto3Paginator):
+class DescribeOpsItemsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeOpsItems)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeopsitemspaginator)
@@ -677,7 +676,7 @@ class DescribeOpsItemsPaginator(Boto3Paginator):
         """
 
 
-class DescribeParametersPaginator(Boto3Paginator):
+class DescribeParametersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeParameters)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describeparameterspaginator)
@@ -696,7 +695,7 @@ class DescribeParametersPaginator(Boto3Paginator):
         """
 
 
-class DescribePatchBaselinesPaginator(Boto3Paginator):
+class DescribePatchBaselinesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribePatchBaselines)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describepatchbaselinespaginator)
@@ -714,7 +713,7 @@ class DescribePatchBaselinesPaginator(Boto3Paginator):
         """
 
 
-class DescribePatchGroupsPaginator(Boto3Paginator):
+class DescribePatchGroupsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribePatchGroups)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describepatchgroupspaginator)
@@ -732,7 +731,7 @@ class DescribePatchGroupsPaginator(Boto3Paginator):
         """
 
 
-class DescribePatchPropertiesPaginator(Boto3Paginator):
+class DescribePatchPropertiesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribePatchProperties)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describepatchpropertiespaginator)
@@ -752,7 +751,7 @@ class DescribePatchPropertiesPaginator(Boto3Paginator):
         """
 
 
-class DescribeSessionsPaginator(Boto3Paginator):
+class DescribeSessionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeSessions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#describesessionspaginator)
@@ -771,7 +770,7 @@ class DescribeSessionsPaginator(Boto3Paginator):
         """
 
 
-class GetInventoryPaginator(Boto3Paginator):
+class GetInventoryPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetInventory)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#getinventorypaginator)
@@ -791,7 +790,7 @@ class GetInventoryPaginator(Boto3Paginator):
         """
 
 
-class GetInventorySchemaPaginator(Boto3Paginator):
+class GetInventorySchemaPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetInventorySchema)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#getinventoryschemapaginator)
@@ -811,7 +810,7 @@ class GetInventorySchemaPaginator(Boto3Paginator):
         """
 
 
-class GetOpsSummaryPaginator(Boto3Paginator):
+class GetOpsSummaryPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetOpsSummary)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#getopssummarypaginator)
@@ -832,7 +831,7 @@ class GetOpsSummaryPaginator(Boto3Paginator):
         """
 
 
-class GetParameterHistoryPaginator(Boto3Paginator):
+class GetParameterHistoryPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetParameterHistory)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#getparameterhistorypaginator)
@@ -851,7 +850,7 @@ class GetParameterHistoryPaginator(Boto3Paginator):
         """
 
 
-class GetParametersByPathPaginator(Boto3Paginator):
+class GetParametersByPathPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetParametersByPath)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#getparametersbypathpaginator)
@@ -872,7 +871,7 @@ class GetParametersByPathPaginator(Boto3Paginator):
         """
 
 
-class ListAssociationVersionsPaginator(Boto3Paginator):
+class ListAssociationVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListAssociationVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listassociationversionspaginator)
@@ -887,7 +886,7 @@ class ListAssociationVersionsPaginator(Boto3Paginator):
         """
 
 
-class ListAssociationsPaginator(Boto3Paginator):
+class ListAssociationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListAssociations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listassociationspaginator)
@@ -905,7 +904,7 @@ class ListAssociationsPaginator(Boto3Paginator):
         """
 
 
-class ListCommandInvocationsPaginator(Boto3Paginator):
+class ListCommandInvocationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListCommandInvocations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listcommandinvocationspaginator)
@@ -926,7 +925,7 @@ class ListCommandInvocationsPaginator(Boto3Paginator):
         """
 
 
-class ListCommandsPaginator(Boto3Paginator):
+class ListCommandsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListCommands)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listcommandspaginator)
@@ -946,7 +945,7 @@ class ListCommandsPaginator(Boto3Paginator):
         """
 
 
-class ListComplianceItemsPaginator(Boto3Paginator):
+class ListComplianceItemsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListComplianceItems)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listcomplianceitemspaginator)
@@ -966,7 +965,7 @@ class ListComplianceItemsPaginator(Boto3Paginator):
         """
 
 
-class ListComplianceSummariesPaginator(Boto3Paginator):
+class ListComplianceSummariesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListComplianceSummaries)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listcompliancesummariespaginator)
@@ -984,7 +983,7 @@ class ListComplianceSummariesPaginator(Boto3Paginator):
         """
 
 
-class ListDocumentVersionsPaginator(Boto3Paginator):
+class ListDocumentVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListDocumentVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listdocumentversionspaginator)
@@ -999,7 +998,7 @@ class ListDocumentVersionsPaginator(Boto3Paginator):
         """
 
 
-class ListDocumentsPaginator(Boto3Paginator):
+class ListDocumentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListDocuments)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listdocumentspaginator)
@@ -1018,7 +1017,7 @@ class ListDocumentsPaginator(Boto3Paginator):
         """
 
 
-class ListOpsItemEventsPaginator(Boto3Paginator):
+class ListOpsItemEventsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListOpsItemEvents)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listopsitemeventspaginator)
@@ -1036,7 +1035,7 @@ class ListOpsItemEventsPaginator(Boto3Paginator):
         """
 
 
-class ListOpsItemRelatedItemsPaginator(Boto3Paginator):
+class ListOpsItemRelatedItemsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListOpsItemRelatedItems)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listopsitemrelateditemspaginator)
@@ -1055,7 +1054,7 @@ class ListOpsItemRelatedItemsPaginator(Boto3Paginator):
         """
 
 
-class ListOpsMetadataPaginator(Boto3Paginator):
+class ListOpsMetadataPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListOpsMetadata)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listopsmetadatapaginator)
@@ -1073,7 +1072,7 @@ class ListOpsMetadataPaginator(Boto3Paginator):
         """
 
 
-class ListResourceComplianceSummariesPaginator(Boto3Paginator):
+class ListResourceComplianceSummariesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListResourceComplianceSummaries)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listresourcecompliancesummariespaginator)
@@ -1091,7 +1090,7 @@ class ListResourceComplianceSummariesPaginator(Boto3Paginator):
         """
 
 
-class ListResourceDataSyncPaginator(Boto3Paginator):
+class ListResourceDataSyncPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListResourceDataSync)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#listresourcedatasyncpaginator)
